@@ -26,13 +26,16 @@ NULL
 
 ## A fix to let CRAN check NOTEs diasappear for non-standard-evaluation used
 ## cf. http://stackoverflow.com/questions/9439256/how-can-i-handle-r-cmd-check-no-visible-binding-for-global-variable-notes-when
-globalVariables(c("one_of", ".", "matches", "starts_with", # dplyr
-                  "manifesto_id", "country", "party", "edate", # general dataset
-                  "md5sum_text.x", "md5sum_text.y", # & metadata
+globalVariables(c("one_of", ".", "matches", "starts_with", "contains", # dplyr
+                  "manifesto_id", "country", "party", "edate", "per0", # general dataset
+                  "md5sum_text.x", "md5sum_text.y", "code", # & metadata & api download
                   "download", "url_original", "is_primary_doc",
                   "name", "tag", # metadata versions
                   "leadedate", "leglength", "festername", "w", "p", # scaling
                   "p_lead", "p_lag", "lrcorescores", # median_voter_single
                   "position", "voteshare", "cumvoteshare",
-                  "above50", "contains_median", "leftbound", "rightbound"
+                  "above50", "contains_median", "leftbound", "rightbound",
+                  "min_divers", "max_divers", "nicheness", "min_nic", ## nicheness
+                  "max_nic", "specialization", "min_spec", "max_spec",
+                  "specialization_stand", "specialization_stand_two", "nicheness_stand"
                 ))
